%global namespace 0

%if %{namespace}
%global shortname CuraLulzbot
%else
%global shortname cura
%endif

Name:           cura-lulzbot
Version:        2.6.21
Release:        1%{?dist}
Epoch:		1
Summary:        3D printer control software
License:        AGPLv3+
URL:            https://code.alephobjects.com/project/profile/10/
# git clone https://code.alephobjects.com/source/Cura2.git
# cd Cura2
# git checkout v2.6.19
# git archive --format=tar.gz --prefix=cura-lulzbot-%{version}/ v2.6.19 > ../cura-lulzbot-%{version}.tar.gz
Source0:	cura-lulzbot-%{version}.tar.gz
BuildArch:      noarch
Patch0:		cura-lulzbot-2.6.19-system.patch

# There are Python plugins in /usr/lib/cura
# We need to byte-compile it with Python 3
%global __python %{__python3}

%if %{namespace}
# Do nothing
%else
Conflicts:	cura
%endif

BuildRequires:  cmake
BuildRequires:  desktop-file-utils
BuildRequires:  dos2unix
BuildRequires:  gettext
BuildRequires:  git
BuildRequires:  python3-devel
BuildRequires:  python3-pytest
BuildRequires:  python3-lulzbot-uranium == %{version}

Requires:       open-sans-fonts
Requires:       python3-pyserial
Requires:       python3-savitar >= 2.6
Requires:       python3-lulzbot-uranium == %{version}
Requires:       python3-zeroconf
Requires:       qt5-qtquickcontrols
Requires:       CuraEngine >= %{epoch}:2.6
# lulzbot package has the materials inside it, does not conflict
# Requires:       cura-fdm-materials == %{version}

# So that it just works
Requires:       3dprinter-udev-rules

%description
Cura is a project which aims to be an single software solution for 3D printing.
While it is developed to be used with the Ultimaker 3D printer, it can be used
with other RepRap based designs.

Cura prepares your model for 3D printing. For novices, it makes it easy to get
great results. For experts, there are over 200 settings to adjust to your
needs. As it's open source, our community helps enrich it even more.

This is the Lulzbot fork of Cura2.

%prep
%setup -q -n cura-lulzbot-%{version}
%if %{namespace}
%patch0 -p1 -b .system
%endif

# The setup.py is only useful for py2exe, remove it, so noone is tempted to use it
rm setup.py

# Upstream installs to lib/python3/dist-packages
# We want to install to %%{python3_sitelib}
sed -i 's|lib/python${PYTHON_VERSION_MAJOR}/dist-packages|%(echo %{python3_sitelib} | sed -e s@%{_prefix}/@@)|g' CMakeLists.txt

# Wrong end of line encoding
dos2unix docs/How_to_use_the_flame_graph_profiler.md

# Wrong shebang
sed -i '1s=^#!/usr/bin/\(python\|env python\)3*=#!%{__python3}=' cura_app.py

# Invalid locale name ptbr
# https://github.com/Ultimaker/Uranium/issues/246
mv resources/i18n/{ptbr,pt_BR}
sed -i 's/"Language: ptbr\n"/"Language: pt_BR\n"/' resources/i18n/pt_BR/*.po

# mkdir CuraLulzbot
# mv cura CuraLulzbot/
# ln -s cura_lulzbot cura

%if %{namespace}
# Relocate imports - don't write patch for this, as this sed needs no rebasing ;)
find -name \*.py -exec sed -i \
  -e 's/from cura import/from CuraLulzbot.cura import/g' \
  -e 's/from cura\./from CuraLulzbot.cura./g' \
  -e 's/import cura/import CuraLulzbot.cura/g' {} \;

find -name \*.py -exec sed -i \
  -e 's/from UM import/from CuraLulzbot.UM import/g' \
  -e 's/from UM\./from CuraLulzbot.UM./g' \
  -e 's| UM\.| CuraLulzbot.UM.|g' \
  -e 's|(UM.Qt|(CuraLulzbot.UM.Qt|g' \
  -e 's/@UM\./@CuraLulzbot.UM./g' \
  -e 's|UM.Settings.Models.SettingVisibilityHandler.SettingVisibilityHandler|CuraLulzbot.UM.Settings.Models.SettingVisibilityHandler.SettingVisibilityHandler|g' \
  -e 's/import UM\./import CuraLulzbot.UM./g' {} \;

find -name \*.qml -exec sed -i \
  -e 's| UM\.| CuraLulzbot.UM.|g' \
  -e 's|import UM|import CuraLulzbot.UM|g' {} \;

# fixup the app specially
sed -i -e 's|cura.CrashHandler.show|CuraLulzbot.cura.CrashHandler.show|g' \
  -e 's|cura.Settings.CuraContainerRegistry.CuraContainerRegistry|CuraLulzbot.cura.Settings.CuraContainerRegistry.CuraContainerRegistry|g' \
  -e 's|cura.CuraApplication.CuraApplication.|CuraLulzbot.cura.CuraApplication.CuraApplication.|g' cura_app.py

# fixup tests
sed -i -e 's|cura.Settings.ExtruderStack.ExtruderStack|CuraLulzbot.cura.Settings.ExtruderStack.ExtruderStack|g' \
  -e 's|cura.Settings.CuraContainerStack|CuraLulzbot.cura.Settings.CuraContainerStack|g' \
  -e 's|cura.Settings.ExtruderStack)|CuraLulzbot.cura.Settings.ExtruderStack)|g' tests/Settings/TestExtruderStack.py
sed -i -e 's| cura.Settings.GlobalStack| CuraLulzbot.cura.Settings.GlobalStack|g' \
  -e 's| cura.Settings.CuraContainerStack| CuraLulzbot.cura.Settings.CuraContainerStack|g' \
  -e 's|(cura.Settings.CuraContainerStack|(CuraLulzbot.cura.Settings.CuraContainerStack|g' \
  -e 's|\[cura.Settings.CuraContainerStack|\[CuraLulzbot.cura.Settings.CuraContainerStack|g' \
  -e 's|cura.Settings.CuraContainerStack.DefinitionContainer|CuraLulzbot.cura.Settings.CuraContainerStack.DefinitionContainer|g' tests/Settings/TestGlobalStack.py
sed -i -e 's|cura.Settings.GlobalStack.GlobalStack|CuraLulzbot.cura.Settings.GlobalStack.GlobalStack|g' tests/Settings/TestCuraContainerRegistry.py

sed -i -e 's|UM.Settings.InstanceContainer.setContainerRegistry|CuraLulzbot.UM.Settings.InstanceContainer.setContainerRegistry|g' \
  -e 's|UM.Settings.ContainerStack.setContainerRegistry|CuraLulzbot.UM.Settings.ContainerStack.setContainerRegistry|g' \
  -e 's|UM.Settings.ContainerStack.ContainerStack|CuraLulzbot.UM.Settings.ContainerStack.ContainerStack|g' \
  -e 's|UM.Settings.ContainerRegistry.ContainerRegistry.addContainer|CuraLulzbot.UM.Settings.ContainerRegistry.ContainerRegistry.addContainer|g' \
  -e 's|UM.Settings.InstanceContainer.InstanceContainer|CuraLulzbot.UM.Settings.InstanceContainer.InstanceContainer|g' \
  -e 's|UM.Settings.ContainerRegistry.addContainer|CuraLulzbot.UM.Settings.ContainerRegistry.addContainer|g' \
  -e 's|UM.Settings.ContainerRegistry._EmptyInstanceContainer|CuraLulzbot.UM.Settings.ContainerRegistry._EmptyInstanceContainer|g' tests/Settings/TestCuraContainerRegistry.py

sed -i -e 's|UM.Settings.ContainerRegistry.ContainerRegistry._ContainerRegistry__instance|CuraLulzbot.UM.Settings.ContainerRegistry.ContainerRegistry._ContainerRegistry__instance|g' \
  -e 's|UM.Settings.ContainerStack._containerRegistry|CuraLulzbot.UM.Settings.ContainerStack._containerRegistry|g' \
  -e 's|UM.Settings.ContainerStack.ContainerStack.deserialize|CuraLulzbot.UM.Settings.ContainerStack.ContainerStack.deserialize|g' \
  -e 's|UM.Settings.ContainerStack.InvalidContainerStackError|CuraLulzbot.UM.Settings.ContainerStack.InvalidContainerStackError|g' tests/Settings/TestExtruderStack.py

sed -i -e 's|UM.Settings.ContainerRegistry.ContainerRegistry._ContainerRegistry__instance|CuraLulzbot.UM.Settings.ContainerRegistry.ContainerRegistry._ContainerRegistry__instance|g' \
  -e 's|UM.Settings.ContainerStack._containerRegistry|CuraLulzbot.UM.Settings.ContainerStack._containerRegistry|g' \
  -e 's|UM.Settings.ContainerStack.ContainerStack.deserialize|CuraLulzbot.UM.Settings.ContainerStack.ContainerStack.deserialize|g' \
  -e 's|UM.Settings.ContainerStack.InvalidContainerStackError|CuraLulzbot.UM.Settings.ContainerStack.InvalidContainerStackError|g' tests/Settings/TestGlobalStack.py

sed -i -e 's|"UM"|"CuraLulzbot.UM"|g' plugins/LayerView/__init__.py
sed -i -e 's|(UM|(CuraLulzbot.UM|g' plugins/LayerView/LayerView.qml
sed -i -e 's|!UM.|!CuraLulzbot.UM.|g' plugins/LayerView/LayerView.qml
sed -i -e 's|*UM.|*CuraLulzbot.UM.|g' plugins/LayerView/LayerView.qml

sed -i -e 's|CuraLulzbot.CuraLulzbot.|CuraLulzbot.|g' tests/Settings/*.py
%endif

%build
%{cmake} -DCURA_VERSION:STRING=%{version} .
make %{?_smp_mflags}

# rebuild locales
cd resources/i18n
rm *.pot
for DIR in *; do
  pushd $DIR
  for FILE in *.po; do
    msgfmt $FILE -o LC_MESSAGES/${FILE%po}mo || :
  done
  popd
done
cd -

%install
make install DESTDIR=%{buildroot}

# Sanitize the location of locale files
pushd %{buildroot}%{_datadir}
mv %{shortname}/resources/i18n locale
ln -s ../../locale %{shortname}/resources/i18n
rm locale/*/*.po
popd

# Unbundle fonts
rm -rf %{buildroot}%{_datadir}/%{shortname}/resources/themes/cura/fonts/
ln -s %{_datadir}/fonts/open-sans/ %{buildroot}%{_datadir}/%{shortname}/resources/themes/cura/fonts

%if %{namespace}
# mv files to avoid conflict
mv %{buildroot}%{_datadir}/applications/cura2.desktop %{buildroot}%{_datadir}/applications/%{name}.desktop
mv %{buildroot}%{_datadir}/appdata/cura.appdata.xml %{buildroot}%{_datadir}/appdata/%{name}.appdata.xml
mv %{buildroot}%{_datadir}/mime/packages/cura.xml %{buildroot}%{_datadir}/mime/packages/%{name}.xml
mv %{buildroot}%{_bindir}/cura2 %{buildroot}%{_bindir}/cura2-lulzbot
%endif

%find_lang cura
%find_lang fdmextruder.def.json
%find_lang fdmprinter.def.json


%check
%if %{namespace}
mkdir CuraLulzbot
ln -s ../cura CuraLulzbot/cura
%endif
%{__python3} -m pytest -v
desktop-file-validate %{buildroot}%{_datadir}/applications/%{shortname}2.desktop



%files -f cura.lang -f fdmextruder.def.json.lang -f fdmprinter.def.json.lang
%license LICENSE
%doc README.md
# CHANGES is not updated since 15.x
# things in docs are developer orianted
%{python3_sitelib}/%{shortname}
%{_datadir}/%{shortname}
%{_datadir}/applications/%{shortname}2.desktop
%{_datadir}/appdata/%{shortname}.appdata.xml
%{_datadir}/mime/packages/%{shortname}.xml
%{_bindir}/%{shortname}2
%{_prefix}/lib/%{shortname}

%changelog
* Tue Aug  8 2017 Tom Callaway <spot@fedoraproject.org> - 1:2.6.21-1
- update to 2.6.21

* Thu Jul 27 2017 Tom Callaway <spot@fedoraproject.org> - 1:2.6.19-1
- lulzbot version (forked from Miro's spec)

* Thu Jul 20 2017 Miro Hrončok <mhroncok@redhat.com> - 1:2.6.1-2
- Require cura-fdm-materials

* Wed Jun 28 2017 Miro Hrončok <mhroncok@redhat.com> - 1:2.6.1-1
- Updated to 2.6.1

* Wed May 10 2017 Miro Hrončok <mhroncok@redhat.com> - 1:2.5.0-2
- Require qt5-qtquickcontrols

* Wed May 03 2017 Miro Hrončok <mhroncok@redhat.com> - 1:2.5.0-1
- Update to modern Cura 2.x (introduce Epoch) (#1393176)

* Fri Feb 10 2017 Fedora Release Engineering <releng@fedoraproject.org> - 15.04.4-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Thu Nov 03 2016 Miro Hrončok <mhroncok@redhat.com> - 15.04.4-5
- Explicitly run cura on X11 GDK backend (#1388953)

* Tue Jul 19 2016 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 15.04.4-4
- https://fedoraproject.org/wiki/Changes/Automatic_Provides_for_Python_RPM_Packages

* Fri Mar 25 2016 Miro Hrončok <mhroncok@redhat.com> - 15.04.4-3
- Require 3dprinter-udev-rules

* Wed Feb 03 2016 Fedora Release Engineering <releng@fedoraproject.org> - 15.04.4-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Sat Jan 30 2016 Miro Hrončok <mhroncok@redhat.com> - 15.04.4-1
- New version

* Wed Jul 08 2015 Miro Hrončok <mhroncok@redhat.com> - 15.02.1-4
- No longer depend on pypy
- Simplify the launcher

* Mon Jul 06 2015 Miro Hrončok <mhroncok@redhat.com> - 15.02.1-3
- Patch for #1230281

* Mon Jul 06 2015 Miro Hrončok <mhroncok@redhat.com> - 15.02.1-2
- Require latest CuraEngine

* Mon Jul 06 2015 Miro Hrončok <mhroncok@redhat.com> - 15.02.1-1
- Update to 15.02.1

* Wed Jun 17 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 14.12.1-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Fri May 29 2015 Miro Hrončok <mhroncok@redhat.com> - 14.12.1-4
- Patch: Open directories with xdg-open (#1217961)

* Mon Apr 20 2015 Miro Hrončok <mhroncok@redhat.com> - 14.12.1-3
- Handle files from the command line (#1213220)

* Mon Mar 30 2015 Miro Hrončok <mhroncok@redhat.com> - 14.12.1-2
- Update the no firmware patch according to communication with Cura upstream

* Mon Dec 29 2014 Miro Hrončok <mhroncok@redhat.com> - 14.12.1-1
- Updated to 14.12.1
- No longer depend on firmware

* Sat Oct 25 2014 Miro Hrončok <mhroncok@redhat.com> - 14.09-1
- New version 14.09

* Tue Jun 24 2014 Miro Hrončok <mhroncok@redhat.com> - 14.06-2
- Require at least the firmware version originally bundled in git

* Mon Jun 23 2014 Miro Hrončok <mhroncok@redhat.com> - 14.06-1
- New version 14.06

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 13.11.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Sat Dec 14 2013 Miro Hrončok <mhroncok@redhat.com> - 13.11.2-1
- New version 13.11.2

* Wed Oct 16 2013 Miro Hrončok <mhroncok@redhat.com> - 13.10-1
- New upstream release with CuraEngine

* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 13.04-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Tue May 07 2013 Miro Hrončok <mhroncok@redhat.com> - 13.04-2
- Remove resources directory before trying to create a symlink there

* Sat May 04 2013 Miro Hrončok <mhroncok@redhat.com> - 13.04-1
- New upstream release
- Fixed missing slice module

* Sat Apr 20 2013 Miro Hrončok <mhroncok@redhat.com> - 13.03-1
- New upstream release

* Tue Feb 19 2013 Miro Hrončok <mhroncok@redhat.com> - 12.12-3
- chmod 755 cura-stripper.sh
- Use firmware from ultimaker-marlin-firmware package
- removed bundling note

* Sun Jan 20 2013 Miro Hrončok <mhroncok@redhat.com> - 12.12-2
- Launcher is in Python now

* Sun Jan 13 2013 Miro Hrončok <mhroncok@redhat.com> - 12.12-1
- First version

